@@ -40,6 +40,24 @@
 #include "tracker-extract.h"
 #include "tracker-read.h"
 
+static gboolean
+allow_file (GSList      *text_allowlist_patterns,
+            GFile       *file)
+{
+	GSList *l;
+	g_autofree gchar *basename = NULL;
+
+	basename = g_file_get_basename (file);
+
+	for (l = text_allowlist_patterns; l; l = l->next) {
+		if (g_pattern_match_string (l->data, basename)) {
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 static gchar *
 get_file_content (GFile   *file,
                   gsize    n_bytes,
@@ -81,34 +99,40 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 {
 	TrackerResource *metadata;
 	TrackerConfig *config;
+	GFile *file;
+	GSList *text_allowlist_patterns;
 	gchar *content = NULL;
 	GError *error = NULL;
 
 	config = tracker_main_get_config ();
+	text_allowlist_patterns = tracker_config_get_text_allowlist_patterns (config);
+	file = tracker_extract_info_get_file (info);
 
-	content = get_file_content (tracker_extract_info_get_file (info),
-	                            tracker_config_get_max_bytes (config),
-	                            &error);
+	if (allow_file (text_allowlist_patterns, file)) {
+		content = get_file_content (tracker_extract_info_get_file (info),
+		                            tracker_config_get_max_bytes (config),
+		                            &error);
 
-	if (error != NULL) {
-		/* An error occurred, perhaps the file was deleted. */
-		g_message ("Error extracting content: %s", error->message);
-		g_error_free (error);
-		return FALSE;
+		if (error != NULL) {
+			/* An error occurred, perhaps the file was deleted. */
+			g_message ("Error extracting content: %s", error->message);
+			g_error_free (error);
+			return FALSE;
+		}
+
+		metadata = tracker_resource_new (NULL);
+		tracker_resource_add_uri (metadata, "rdf:type", "nfo:PlainTextDocument");
+
+		if (content) {
+			tracker_resource_set_string (metadata, "nie:plainTextContent", content);
+			g_free (content);
+		} else {
+			tracker_resource_set_string (metadata, "nie:plainTextContent", "");
+		}
+
+		tracker_extract_info_set_resource (info, metadata);
+		g_object_unref (metadata);
 	}
 
-	metadata = tracker_resource_new (NULL);
-	tracker_resource_add_uri (metadata, "rdf:type", "nfo:PlainTextDocument");
-
-	if (content) {
-		tracker_resource_set_string (metadata, "nie:plainTextContent", content);
-		g_free (content);
-	} else {
-		tracker_resource_set_string (metadata, "nie:plainTextContent", "");
-	}
-
-	tracker_extract_info_set_resource (info, metadata);
-	g_object_unref (metadata);
-
 	return TRUE;
 }
